@@ -13,13 +13,14 @@ class Node:
         self.countAns = {}
 
 def __orderdata__(data, answerCol):
+    data = data.astype("str")
     for col in data.columns:
         if len(data[col]) == len(pd.unique(data[col])):
             data = data.drop(col, axis = 1)
     features = [feat for feat in data]
     features.remove(answerCol)
     
-    return features
+    return data, features
 
 
 def __entropy__(data, answerCol):
@@ -82,7 +83,7 @@ def __id3_bg__(data, features, answerCol):
         return root
 
 def ID3(data, answerCol):
-    features = __orderdata__(data, answerCol)
+    data, features = __orderdata__(data, answerCol)
     return __id3_bg__(data, features, answerCol)
 
 def printTree(root: Node, depth=0):
@@ -109,4 +110,4 @@ def printTree(root: Node, depth=0):
         print()
         for child in root.children:
             printTree(child, depth + 1)
-        n += 1
+        n += 1
\ No newline at end of file
